summaryrefslogtreecommitdiff
path: root/IntelFrameworkModulePkg
diff options
context:
space:
mode:
authorklu2 <klu2@6f19259b-4bc3-4df7-8a09-765794883524>2009-06-19 07:45:13 +0000
committerklu2 <klu2@6f19259b-4bc3-4df7-8a09-765794883524>2009-06-19 07:45:13 +0000
commit13078b3fadb4aaae2d6975ab96a7ad649017589f (patch)
treed73d64c3998f0fbae1d22383fb879c717efbd6bc /IntelFrameworkModulePkg
parentf713c4feab0ea6364d300f0fbe27322609152c4c (diff)
downloadedk2-platforms-13078b3fadb4aaae2d6975ab96a7ad649017589f.tar.xz
1) Make naming of enumeration type follows coding style
2) Add missing parameter in function description. git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@8606 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'IntelFrameworkModulePkg')
-rw-r--r--IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BBSsupport.c4
-rw-r--r--IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.c18
-rw-r--r--IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.h68
-rw-r--r--IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/ConsoleOption.c10
-rw-r--r--IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/FileExplorer.c34
-rw-r--r--IntelFrameworkModulePkg/Universal/BdsDxe/FrontPage.c2
-rw-r--r--IntelFrameworkModulePkg/Universal/BdsDxe/String.c4
-rw-r--r--IntelFrameworkModulePkg/Universal/BdsDxe/String.h4
8 files changed, 59 insertions, 85 deletions
diff --git a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BBSsupport.c b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BBSsupport.c
index 765c77bf55..044e1387e8 100644
--- a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BBSsupport.c
+++ b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BBSsupport.c
@@ -3,7 +3,7 @@
and manage the legacy boot option, all legacy boot option is getting from
the legacy BBS table.
-Copyright (c) 2004 - 2008, Intel Corporation. <BR>
+Copyright (c) 2004 - 2009, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -1482,7 +1482,7 @@ BdsSetBootPriority4SameTypeDev (
Print the BBS Table.
@param LocalBbsTable The BBS table.
-
+ @param BbsCount The count of entry in BBS table.
**/
VOID
PrintBbsTable (
diff --git a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.c b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.c
index da5611d2de..c0fd073aaa 100644
--- a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.c
+++ b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.c
@@ -1,7 +1,7 @@
/** @file
The functions for Boot Maintainence Main menu.
-Copyright (c) 2004 - 2008, Intel Corporation. <BR>
+Copyright (c) 2004 - 2009, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -450,7 +450,7 @@ BootMaintCallback (
if (QuestionId < CONFIG_OPTION_OFFSET) {
switch (QuestionId) {
case KEY_VALUE_BOOT_FROM_FILE:
- Private->FeCurrentState = BOOT_FROM_FILE_STATE;
+ Private->FeCurrentState = FileExplorerStateBootFromFile;
//
// Exit Bmm main formset to send File Explorer formset.
@@ -459,7 +459,7 @@ BootMaintCallback (
break;
case FORM_BOOT_ADD_ID:
- Private->FeCurrentState = ADD_BOOT_OPTION_STATE;
+ Private->FeCurrentState = FileExplorerStateAddBootOption;
//
// Exit Bmm main formset to send File Explorer formset.
@@ -468,7 +468,7 @@ BootMaintCallback (
break;
case FORM_DRV_ADD_FILE_ID:
- Private->FeCurrentState = ADD_DRIVER_OPTION_STATE;
+ Private->FeCurrentState = FileExplorerStateAddDriverOptionState;
//
// Exit Bmm main formset to send File Explorer formset.
@@ -890,8 +890,8 @@ InitializeBM (
BmmCallbackInfo->FeConfigAccess.ExtractConfig = FakeExtractConfig;
BmmCallbackInfo->FeConfigAccess.RouteConfig = FakeRouteConfig;
BmmCallbackInfo->FeConfigAccess.Callback = FileExplorerCallback;
- BmmCallbackInfo->FeCurrentState = INACTIVE_STATE;
- BmmCallbackInfo->FeDisplayContext = UNKNOWN_CONTEXT;
+ BmmCallbackInfo->FeCurrentState = FileExplorerStateInActive;
+ BmmCallbackInfo->FeDisplayContext = FileExplorerDisplayUnknown;
//
// Install Device Path Protocol and Config Access protocol to driver handle
@@ -1355,7 +1355,7 @@ FormSetDispatcher (
//
// When this Formset returns, check if we are going to explore files.
//
- if (INACTIVE_STATE != CallbackData->FeCurrentState) {
+ if (FileExplorerStateInActive != CallbackData->FeCurrentState) {
UpdateFileExplorer (CallbackData, 0);
ActionRequest = EFI_BROWSER_ACTION_REQUEST_NONE;
@@ -1372,8 +1372,8 @@ FormSetDispatcher (
EnableResetRequired ();
}
- CallbackData->FeCurrentState = INACTIVE_STATE;
- CallbackData->FeDisplayContext = UNKNOWN_CONTEXT;
+ CallbackData->FeCurrentState = FileExplorerStateInActive;
+ CallbackData->FeDisplayContext = FileExplorerDisplayUnknown;
ReclaimStringDepository ();
} else {
break;
diff --git a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.h b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.h
index 1a6f076ecc..781c747a35 100644
--- a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.h
+++ b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.h
@@ -1,7 +1,7 @@
/** @file
Header file for boot maintenance module.
-Copyright (c) 2004 - 2008, Intel Corporation. <BR>
+Copyright (c) 2004 - 2009, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -93,53 +93,25 @@ extern UINT8 FEBin[];
//
typedef UINT8 BBS_TYPE;
-typedef enum {
- PC_ANSI = 0,
- VT_100,
- VT_100_PLUS,
- VT_UTF8
+typedef enum _TYPE_OF_TERMINAL {
+ TerminalTypePcAnsi = 0,
+ TerminalTypeVt100,
+ TerminalTypeVt100Plus,
+ TerminalTypeVtUtf8
} TYPE_OF_TERMINAL;
-typedef enum {
- COM1 = 0,
- COM2,
- UNKNOW_COM
-} TYPE_OF_COM;
-
-typedef enum {
- CONIN = 0,
- CONOUT,
- CONERR,
- UNKNOWN_CON
-} TYPE_OF_CON;
-
-typedef enum {
- BAUDRATE = 0,
- DATABITS,
- PARITY,
- STOPBITS,
- UNKNOW_ATTR
-} TYPE_OF_ATTRIBUTE;
-
-typedef enum {
- MANNER_GOTO = 0,
- MANNER_CHECK,
- MANNER_ONEOF,
- MANNER_USER_DEFINE
-} TYPE_OF_UPATE_MANNER;
-
-typedef enum {
- INACTIVE_STATE = 0,
- BOOT_FROM_FILE_STATE,
- ADD_BOOT_OPTION_STATE,
- ADD_DRIVER_OPTION_STATE,
- UNKNOWN_STATE
+typedef enum _FILE_EXPLORER_STATE {
+ FileExplorerStateInActive = 0,
+ FileExplorerStateBootFromFile,
+ FileExplorerStateAddBootOption,
+ FileExplorerStateAddDriverOptionState,
+ FileExplorerStateUnknown
} FILE_EXPLORER_STATE;
-typedef enum {
- FILE_SYSTEM,
- DIRECTORY,
- UNKNOWN_CONTEXT
+typedef enum _FILE_EXPLORER_DISPLAY_CONTEXT {
+ FileExplorerDisplayFileSystem,
+ FileExplorerDisplayDirectory,
+ FileExplorerDisplayUnknown
} FILE_EXPLORER_DISPLAY_CONTEXT;
//
@@ -436,10 +408,12 @@ typedef struct {
FILE_EXPLORER_NV_DATA FeFakeNvData;
} BMM_CALLBACK_DATA;
-typedef struct _STRING_LIST_NODE {
+typedef struct _STRING_LIST_NODE STRING_LIST_NODE;
+
+struct _STRING_LIST_NODE {
EFI_STRING_ID StringToken;
- struct _STRING_LIST_NODE *Next;
-} STRING_LIST_NODE;
+ STRING_LIST_NODE *Next;
+};
typedef struct _STRING_DEPOSITORY {
UINTN TotalNodeNumber;
diff --git a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/ConsoleOption.c b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/ConsoleOption.c
index 5ab898959e..06fd0e0af7 100644
--- a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/ConsoleOption.c
+++ b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/ConsoleOption.c
@@ -1,7 +1,7 @@
/** @file
handles console redirection from boot manager
-Copyright (c) 2004 - 2008, Intel Corporation. <BR>
+Copyright (c) 2004 - 2009, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -864,19 +864,19 @@ IsTerminalDevicePath (
CopyMem (&TempGuid, &Vendor->Guid, sizeof (EFI_GUID));
if (CompareGuid (&TempGuid, &TerminalTypeGuid[0])) {
- *Termi = PC_ANSI;
+ *Termi = TerminalTypePcAnsi;
IsTerminal = TRUE;
} else {
if (CompareGuid (&TempGuid, &TerminalTypeGuid[1])) {
- *Termi = VT_100;
+ *Termi = TerminalTypeVt100;
IsTerminal = TRUE;
} else {
if (CompareGuid (&TempGuid, &TerminalTypeGuid[2])) {
- *Termi = VT_100_PLUS;
+ *Termi = TerminalTypeVt100Plus;
IsTerminal = TRUE;
} else {
if (CompareGuid (&TempGuid, &TerminalTypeGuid[3])) {
- *Termi = VT_UTF8;
+ *Termi = TerminalTypeVtUtf8;
IsTerminal = TRUE;
} else {
IsTerminal = FALSE;
diff --git a/IntelFrameworkModulePkg/Universal/BdsDxe/FrontPage.c b/IntelFrameworkModulePkg/Universal/BdsDxe/FrontPage.c
index 5a3443bbe3..2098602b2f 100644
--- a/IntelFrameworkModulePkg/Universal/BdsDxe/FrontPage.c
+++ b/IntelFrameworkModulePkg/Universal/BdsDxe/FrontPage.c
@@ -620,7 +620,7 @@ GetProducerString (
}
/**
- Convert Processor Frequency Data to a string
+ Convert Processor Frequency Data to a string.
@param ProcessorFrequency The frequency data to process
@param String The string that is created
diff --git a/IntelFrameworkModulePkg/Universal/BdsDxe/String.c b/IntelFrameworkModulePkg/Universal/BdsDxe/String.c
index ccabd3239d..7aeaebb8aa 100644
--- a/IntelFrameworkModulePkg/Universal/BdsDxe/String.c
+++ b/IntelFrameworkModulePkg/Universal/BdsDxe/String.c
@@ -1,7 +1,7 @@
/** @file
String support
-Copyright (c) 2004 - 2008, Intel Corporation. <BR>
+Copyright (c) 2004 - 2009, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -23,7 +23,7 @@ EFI_GUID mBdsStringPackGuid = {
};
/**
- Initialize HII global accessor for string support
+ Initialize HII global accessor for string support.
**/
VOID
diff --git a/IntelFrameworkModulePkg/Universal/BdsDxe/String.h b/IntelFrameworkModulePkg/Universal/BdsDxe/String.h
index 4b8efa4345..1b69104a7a 100644
--- a/IntelFrameworkModulePkg/Universal/BdsDxe/String.h
+++ b/IntelFrameworkModulePkg/Universal/BdsDxe/String.h
@@ -1,7 +1,7 @@
/** @file
String support
-Copyright (c) 2004 - 2008, Intel Corporation. <BR>
+Copyright (c) 2004 - 2009, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -50,7 +50,7 @@ GetStringById (
);
/**
- Initialize HII global accessor for string support
+ Initialize HII global accessor for string support.
**/
VOID
diff --git a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/FileExplorer.c b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/FileExplorer.c
index 2cde6e0d0f..2eaf9b2d59 100644
--- a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/FileExplorer.c
+++ b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/FileExplorer.c
@@ -1,7 +1,7 @@
/** @file
File explorer related functions.
-Copyright (c) 2004 - 2008, Intel Corporation. <BR>
+Copyright (c) 2004 - 2009, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -47,9 +47,9 @@ UpdateFileExplorePage (
continue;
}
- if ((NewFileContext->IsDir) || (BOOT_FROM_FILE_STATE == CallbackData->FeCurrentState)) {
+ if ((NewFileContext->IsDir) || (FileExplorerStateBootFromFile == CallbackData->FeCurrentState)) {
//
// Create Text opcode for directory, also create Text opcode for file in BOOT_FROM_FILE_STATE.
//
HiiCreateActionOpCode (
mStartOpCodeHandle,
@@ -61,11 +61,11 @@ UpdateFileExplorePage (
);
} else {
//
// Create Goto opcode for file in ADD_BOOT_OPTION_STATE or ADD_DRIVER_OPTION_STATE.
//
- if (ADD_BOOT_OPTION_STATE == CallbackData->FeCurrentState) {
+ if (FileExplorerStateAddBootOption == CallbackData->FeCurrentState) {
FormId = FORM_BOOT_ADD_DESCRIPTION_ID;
- } else if (ADD_DRIVER_OPTION_STATE == CallbackData->FeCurrentState) {
+ } else if (FileExplorerStateAddDriverOptionState == CallbackData->FeCurrentState) {
FormId = FORM_DRIVER_ADD_FILE_DESCRIPTION_ID;
}
@@ -119,7 +119,7 @@ UpdateFileExplorer (
FileOptionMask = (UINT16) (FILE_OPTION_MASK & KeyValue);
- if (UNKNOWN_CONTEXT == CallbackData->FeDisplayContext) {
+ if (FileExplorerDisplayUnknown == CallbackData->FeDisplayContext) {
//
// First in, display file system.
//
@@ -129,15 +129,15 @@ UpdateFileExplorer (
UpdateFileExplorePage (CallbackData, &FsOptionMenu);
- CallbackData->FeDisplayContext = FILE_SYSTEM;
+ CallbackData->FeDisplayContext = FileExplorerDisplayFileSystem;
} else {
- if (FILE_SYSTEM == CallbackData->FeDisplayContext) {
+ if (FileExplorerDisplayFileSystem == CallbackData->FeDisplayContext) {
NewMenuEntry = BOpt_GetMenuEntry (&FsOptionMenu, FileOptionMask);
- } else if (DIRECTORY == CallbackData->FeDisplayContext) {
+ } else if (FileExplorerDisplayDirectory == CallbackData->FeDisplayContext) {
NewMenuEntry = BOpt_GetMenuEntry (&DirectoryMenu, FileOptionMask);
}
- CallbackData->FeDisplayContext = DIRECTORY;
+ CallbackData->FeDisplayContext = FileExplorerDisplayDirectory;
NewFileContext = (BM_FILE_CONTEXT *) NewMenuEntry->VariableContext;
@@ -156,7 +156,7 @@ UpdateFileExplorer (
} else {
switch (CallbackData->FeCurrentState) {
- case BOOT_FROM_FILE_STATE:
+ case FileExplorerStateBootFromFile:
//
// Here boot from file
//
@@ -164,9 +164,9 @@ UpdateFileExplorer (
ExitFileExplorer = TRUE;
break;
- case ADD_BOOT_OPTION_STATE:
- case ADD_DRIVER_OPTION_STATE:
- if (ADD_BOOT_OPTION_STATE == CallbackData->FeCurrentState) {
+ case FileExplorerStateAddBootOption:
+ case FileExplorerStateAddDriverOptionState:
+ if (FileExplorerStateAddBootOption == CallbackData->FeCurrentState) {
FormId = FORM_BOOT_ADD_DESCRIPTION_ID;
} else {
FormId = FORM_DRIVER_ADD_FILE_DESCRIPTION_ID;
@@ -267,7 +267,7 @@ FileExplorerCallback (
//
// Apply changes and exit formset
//
- if (ADD_BOOT_OPTION_STATE == Private->FeCurrentState) {
+ if (FileExplorerStateAddBootOption == Private->FeCurrentState) {
Status = Var_UpdateBootOption (Private, NvRamMap);
if (EFI_ERROR (Status)) {
return Status;
@@ -275,7 +275,7 @@ FileExplorerCallback (
BOpt_GetBootOptions (Private);
CreateMenuStringToken (Private, Private->FeHiiHandle, &BootOptionMenu);
- } else if (ADD_DRIVER_OPTION_STATE == Private->FeCurrentState) {
+ } else if (FileExplorerStateAddDriverOptionState == Private->FeCurrentState) {
Status = Var_UpdateDriverOption (
Private,
Private->FeHiiHandle,
@@ -47,9 +47,9 @@ UpdateFileExplorePage (
//
- // Create Text opcode for directory, also create Text opcode for file in BOOT_FROM_FILE_STATE.
+ // Create Text opcode for directory, also create Text opcode for file in FileExplorerStateBootFromFile.
//
HiiCreateActionOpCode (
@@ -61,11 +61,11 @@ UpdateFileExplorePage (
} else {
//
- // Create Goto opcode for file in ADD_BOOT_OPTION_STATE or ADD_DRIVER_OPTION_STATE.
+ // Create Goto opcode for file in FileExplorerStateAddBootOption or FileExplorerStateAddDriverOptionState.
//